@@ -1,20 +1,15 @@
 "SortModes" <-
-function(a.best,prNCP,c.val=0.25){
+function(a.best,c.val=0.25){
   
 ncp <- ncol(a.best$S);
 Ng <- nrow(a.best$S);
 
-pCorr <- prNCP$pCorr ; # need to scale back
-tmpA <- a.best$A;
-for( c in 1:ncp){
-  tmpA[c,] <- sqrt(diag(pCorr)[c])*a.best$A[c,];
-}
-
 #SORTING CRITERION
 
 # A) Computation of relative data power. Store values in vector of size H=ncp. Could use different criterion here.
 # need squared entries
- Ssq <- a.best$S * a.best$S ; Asq <- tmpA * tmpA ;
+ Ssq <- a.best$S * a.best$S ; 
+ Asq <- a.best$A * a.best$A ;
  Xsq <- a.best$X * a.best$X ;
  rdp <- rep(0, times=ncp);
  for ( k in 1:ncp ) {
@@ -22,7 +17,6 @@ for( c in 1:ncp){
  }
  rdp.s <- sort(rdp, na.last=NA,decreasing=TRUE, index.return=TRUE);
 
-
 # B) sorting with mixture of contrast and data variance (Liebermeister)
  JG <- rep(0, times=ncp);
  JA <- rep(0, times=ncp);
@@ -40,7 +34,6 @@ for( c in 1:ncp){
    J <- JG*(c.val/sumJG)+ JA*(1-c.val)/sumJA ;
    J.s <- sort(J, na.last=NA,decreasing=TRUE, index.return=TRUE);
 
-
    return(list(a.best=a.best,rdp=rdp.s,lbm=J.s));
 
 } # END OF FUNCTION
